@@ -16,8 +16,8 @@ class Book(AMaaSModel):
         return ['positions']
 
     def __init__(self, asset_manager_id, book_id=None, book_type='Trading', book_status='Active', owner_id=None,
-                 party_id=None, close_time=datetime.timedelta(hours=18), timezone='UTC', base_currency='USD',
-                 business_unit='', description='', positions=None,
+                 party_id=None, close_time=None, timezone='', base_currency='USD',
+                 business_unit='', reference='', description='', positions=None,
                  *args, **kwargs):
         self.asset_manager_id = asset_manager_id
         self.book_id = book_id or uuid.uuid4().hex
@@ -29,6 +29,7 @@ class Book(AMaaSModel):
         self.timezone = timezone
         self.base_currency = base_currency
         self.business_unit = business_unit
+        self.reference = reference
         self.description = description
         self.positions = positions
         super(Book, self).__init__(*args, **kwargs)
@@ -64,4 +65,4 @@ class Book(AMaaSModel):
         tz = pytz.timezone(self.timezone)
         close_time = datetime.datetime.strptime(self.close_time, '%H:%M:%S').time()
         close_time = tz.localize(datetime.datetime.combine(datetime.datetime.now(tz), close_time))
-        return close_time.astimezone(pytz.utc).time()
\ No newline at end of file
+        return close_time.astimezone(pytz.utc).time()
