@@ -35,7 +35,7 @@ class CorporateAction(AMaaSModel):
         self.description = description
         # Defaults are here not in constructor for mutability reasons.
         self.references = references.copy() if references else {}
-        self.references['AMaaS'] = Reference(reference_value=self.corporate_action_id)  # Upserts the AMaaS Reference
+        self.references['Argomi'] = Reference(reference_value=self.corporate_action_id)  # Upserts the Argomi Reference
 
         super(CorporateAction, self).__init__(*args, **kwargs)
 
